@@ -1,14 +1,24 @@
 # -*- coding: utf-8 -*-
 # Description: sensors netdata python.d plugin
 # Author: Pawel Krupa (paulfantom)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
-from base import SimpleService
-import lm_sensors as sensors
+from third_party import lm_sensors as sensors
+
+from bases.FrameworkServices.SimpleService import SimpleService
 
 # default module values (can be overridden per job in `config`)
 # update_every = 2
 
-ORDER = ['temperature', 'fan', 'voltage', 'current', 'power', 'energy', 'humidity']
+ORDER = [
+    'temperature',
+    'fan',
+    'voltage',
+    'current',
+    'power',
+    'energy',
+    'humidity',
+]
 
 # This is a prototype of chart definition which is used to dynamically create self.definitions
 CHARTS = {
@@ -16,37 +26,44 @@ CHARTS = {
         'options': [None, ' temperature', 'Celsius', 'temperature', 'sensors.temperature', 'line'],
         'lines': [
             [None, None, 'absolute', 1, 1000]
-        ]},
+        ]
+    },
     'voltage': {
         'options': [None, ' voltage', 'Volts', 'voltage', 'sensors.voltage', 'line'],
         'lines': [
             [None, None, 'absolute', 1, 1000]
-        ]},
+        ]
+    },
     'current': {
         'options': [None, ' current', 'Ampere', 'current', 'sensors.current', 'line'],
         'lines': [
             [None, None, 'absolute', 1, 1000]
-        ]},
+        ]
+    },
     'power': {
         'options': [None, ' power', 'Watt', 'power', 'sensors.power', 'line'],
         'lines': [
             [None, None, 'absolute', 1, 1000000]
-        ]},
+        ]
+    },
     'fan': {
         'options': [None, ' fans speed', 'Rotations/min', 'fans', 'sensors.fan', 'line'],
         'lines': [
             [None, None, 'absolute', 1, 1000]
-        ]},
+        ]
+    },
     'energy': {
         'options': [None, ' energy', 'Joule', 'energy', 'sensors.energy', 'areastack'],
         'lines': [
             [None, None, 'incremental', 1, 1000000]
-        ]},
+        ]
+    },
     'humidity': {
         'options': [None, ' humidity', 'Percent', 'humidity', 'sensors.humidity', 'line'],
         'lines': [
             [None, None, 'absolute', 1, 1000]
-        ]}
+        ]
+    }
 }
 
 LIMITS = {
@@ -75,87 +92,76 @@ TYPE_MAP = {
 class Service(SimpleService):
     def __init__(self, configuration=None, name=None):
         SimpleService.__init__(self, configuration=configuration, name=name)
-        self.order = []
-        self.definitions = {}
-        self.celsius = ('Celsius', lambda x: x)
-        self.fahrenheit = ('Fahrenheit', lambda x: x * 9 / 5 + 32)  if self.configuration.get('fahrenheit') else False
-        self.choice = (choice for choice in [self.fahrenheit, self.celsius] if choice)
-        self.chips = []
+        self.order = list()
+        self.definitions = dict()
+        self.chips = list()
 
-    def _get_data(self):
-        data = {}
+    def get_data(self):
+        data = dict()
         try:
             for chip in sensors.ChipIterator():
                 prefix = sensors.chip_snprintf_name(chip)
                 for feature in sensors.FeatureIterator(chip):
                     sfi = sensors.SubFeatureIterator(chip, feature)
+                    val = None
                     for sf in sfi:
-                        val = sensors.get_value(chip, sf.number)
-                        break
-                    typeName = TYPE_MAP[feature.type]
-                    if typeName in LIMITS:
-                        limit = LIMITS[typeName];
+                        try:
+                            val = sensors.get_value(chip, sf.number)
+                            break
+                        except sensors.SensorsError:
+                            continue
+                    if val is None:
+                        continue
+                    type_name = TYPE_MAP[feature.type]
+                    if type_name in LIMITS:
+                        limit = LIMITS[type_name]
                         if val < limit[0] or val > limit[1]:
                             continue
-                    if 'temp' in str(feature.name.decode()):
-                        data[prefix + "_" + str(feature.name.decode())] = int(self.calc(val) * 1000)
-                    else:
-                        data[prefix + "_" + str(feature.name.decode())] = int(val * 1000)
-        except Exception as e:
-            self.error(e)
+                        data[prefix + '_' + str(feature.name.decode())] = int(val * 1000)
+        except sensors.SensorsError as error:
+            self.error(error)
             return None
 
-        if len(data) == 0:
-            return None
-        return data
+        return data or None
 
-    def _create_definitions(self):
-        for type in ORDER:
+    def create_definitions(self):
+        for sensor in ORDER:
             for chip in sensors.ChipIterator():
                 chip_name = sensors.chip_snprintf_name(chip)
-                if len(self.chips) != 0 and not any([chip_name.startswith(ex) for ex in self.chips]):
+                if self.chips and not any([chip_name.startswith(ex) for ex in self.chips]):
                     continue
                 for feature in sensors.FeatureIterator(chip):
                     sfi = sensors.SubFeatureIterator(chip, feature)
-                    vals = [sensors.get_value(chip, sf.number) for sf in sfi]
-                    if vals[0] == 0:
+                    vals = list()
+                    for sf in sfi:
+                        try:
+                            vals.append(sensors.get_value(chip, sf.number))
+                        except sensors.SensorsError as error:
+                            self.error('{0}: {1}'.format(sf.name, error))
+                            continue
+                    if not vals or vals[0] == 0:
                         continue
-                    if TYPE_MAP[feature.type] == type:
+                    if TYPE_MAP[feature.type] == sensor:
                         # create chart
-                        name = chip_name + "_" + TYPE_MAP[feature.type]
+                        name = chip_name + '_' + TYPE_MAP[feature.type]
                         if name not in self.order:
                             self.order.append(name)
-                            chart_def = list(CHARTS[type]['options'])
+                            chart_def = list(CHARTS[sensor]['options'])
                             chart_def[1] = chip_name + chart_def[1]
-                            if chart_def[2] == 'Celsius':
-                                chart_def[2] = self.choice[0]
                             self.definitions[name] = {'options': chart_def}
                             self.definitions[name]['lines'] = []
-                        line = list(CHARTS[type]['lines'][0])
-                        line[0] = chip_name + "_" + str(feature.name.decode())
+                        line = list(CHARTS[sensor]['lines'][0])
+                        line[0] = chip_name + '_' + str(feature.name.decode())
                         line[1] = sensors.get_label(chip, feature)
                         self.definitions[name]['lines'].append(line)
 
     def check(self):
         try:
             sensors.init()
-        except Exception as e:
-            self.error(e)
+        except sensors.SensorsError as error:
+            self.error(error)
             return False
-        
-        try:
-            self.choice = next(self.choice)
-        except StopIteration:
-            # That can not happen but..
-            self.choice = ('Celsius', lambda x: x)
-            self.calc = self.choice[1]
-        else:
-            self.calc = self.choice[1]
 
-        try:
-            self._create_definitions()
-        except Exception as e:
-            self.error(e)
-            return False
+        self.create_definitions()
 
         return True
